@@ -1,7 +1,7 @@
 package JSON::Decode::Regexp;
 
-our $DATE = '2016-03-18'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-03-24'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -142,9 +142,11 @@ our $FROM_JSON = qr{
 ) }xms;
 
 sub from_json {
+    state $re = qr{\A$FROM_JSON\z};
+
     local $_ = shift;
     local $^R;
-    eval { m{\A$FROM_JSON\z}; } and return $_;
+    eval { $_ =~ $re } and return $_;
     die $@ if $@;
     die 'no match';
 }
@@ -164,7 +166,7 @@ JSON::Decode::Regexp - JSON parser as a single Perl Regex
 
 =head1 VERSION
 
-This document describes version 0.06 of JSON::Decode::Regexp (from Perl distribution JSON-Decode-Regexp), released on 2016-03-18.
+This document describes version 0.07 of JSON::Decode::Regexp (from Perl distribution JSON-Decode-Regexp), released on 2016-03-24.
 
 =head1 SYNOPSIS
 
